{% extends "layout.html" %}
{% block content %}
<div>
<h2>{{ data['title'] }}</h2>
<video id="video" class="video-js vjs-default-skin vjs-big-play-centered"
  controls preload="auto" width="1024" height="768" data-setup="{}">
 <source src="{{url_for('testbatch.test_batch_report_file', filename = data['path']) }}" type='video/flv' />
 <p class="vjs-no-js">To view this video please enable JavaScript, and consider upgrading to a web browser that <a href="http://videojs.com/html5-video-support/" target="_blank">supports HTML5 video</a></p>
</video>
</div>
{% endblock %}
